@@ -1,5 +1,6 @@
 # coding=utf-8
 # (C) Copyright 2014-2016 Hewlett Packard Enterprise Development LP
+# Copyright 2017 Fujitsu LIMITED
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +21,6 @@ import mock
 import smtplib
 import socket
 import time
-import unittest
 
 import six
 
@@ -34,6 +34,7 @@ else:
 
 from monasca_notification.notification import Notification
 from monasca_notification.plugins import email_notifier
+from tests import base
 
 UNICODE_CHAR = six.unichr(2344)
 UNICODE_CHAR_ENCODED = UNICODE_CHAR.encode("utf-8")
@@ -113,20 +114,16 @@ class smtpStubException(object):
         raise smtplib.SMTPServerDisconnected
 
 
-class TestEmail(unittest.TestCase):
+class TestEmail(base.PluginTestCase):
     def setUp(self):
+        super(TestEmail, self).setUp(email_notifier.register_opts)
+
         self.trap = []
-
-        self.email_config = {'server': 'my.smtp.server',
-                             'port': 25,
-                             'user': None,
-                             'password': None,
-                             'timeout': 60,
-                             'from_addr': 'hpcs.mon@hp.com',
-                             'grafana_url': 'http://127.0.0.1:3000'}
-
-    def tearDown(self):
-        pass
+        self.conf_override(group='email_notifier', server='my.smtp.server',
+                           port=25, user=None,
+                           password=None, timeout=60,
+                           from_addr='hpcs.mon@hp.com',
+                           grafana_url='http://127.0.0.1:3000')
 
     def _smtpStub(self, *arg, **kwargs):
         return smtpStub(self.trap)
@@ -143,7 +140,6 @@ class TestEmail(unittest.TestCase):
         mock_log.error = self.trap.append
 
         email = email_notifier.EmailNotifier(mock_log)
-        email.config(self.email_config)
 
         alarm_dict = alarm(metric)
 
@@ -165,18 +161,17 @@ class TestEmail(unittest.TestCase):
 
         email = _parse_email(self.trap.pop(0))
 
-        self.assertRegexpMatches(email['from'], 'hpcs.mon@hp.com')
-        self.assertRegexpMatches(email['to'], 'me@here.com')
-        self.assertRegexpMatches(email['raw'], 'Content-Type: text/plain')
-        self.assertRegexpMatches(email['raw'],
-                                 'Content-Transfer-Encoding: base64')
-        self.assertRegexpMatches(email['subject'],
-                                 'ALARM LOW "test Alarm .*" for Host: foo1.*')
-        self.assertRegexpMatches(email['body'], 'Alarm .test Alarm.')
-        self.assertRegexpMatches(email['body'], 'On host .foo1.')
-        self.assertRegexpMatches(email['body'], UNICODE_CHAR)
-        self.assertRegexpMatches(email['body'], 'Link: some-link')
-        self.assertRegexpMatches(email['body'], 'Lifecycle state: OPEN')
+        self.assertRegex(email['from'], 'hpcs.mon@hp.com')
+        self.assertRegex(email['to'], 'me@here.com')
+        self.assertRegex(email['raw'], 'Content-Type: text/plain')
+        self.assertRegex(email['raw'], 'Content-Transfer-Encoding: base64')
+        self.assertRegex(email['subject'],
+                         'ALARM LOW "test Alarm .*" for Host: foo1.*')
+        self.assertRegex(email['body'], 'Alarm .test Alarm.')
+        self.assertRegex(email['body'], 'On host .foo1.')
+        self.assertRegex(email['body'], UNICODE_CHAR)
+        self.assertRegex(email['body'], 'Link: some-link')
+        self.assertRegex(email['body'], 'Lifecycle state: OPEN')
 
         return_value = self.trap.pop(0)
         self.assertTrue(return_value)
@@ -195,16 +190,15 @@ class TestEmail(unittest.TestCase):
 
         email = _parse_email(self.trap.pop(0))
 
-        self.assertRegexpMatches(email['from'], 'hpcs.mon@hp.com')
-        self.assertRegexpMatches(email['to'], 'me@here.com')
-        self.assertRegexpMatches(email['raw'], 'Content-Type: text/plain')
-        self.assertRegexpMatches(email['raw'],
-                                 'Content-Transfer-Encoding: base64')
-        self.assertRegexpMatches(email['subject'],
-                                 'ALARM LOW .test Alarm.* Target: some_where')
-        self.assertRegexpMatches(email['body'], "Alarm .test Alarm.")
-        self.assertRegexpMatches(email['body'], "On host .foo1.")
-        self.assertRegexpMatches(email['body'], UNICODE_CHAR)
+        self.assertRegex(email['from'], 'hpcs.mon@hp.com')
+        self.assertRegex(email['to'], 'me@here.com')
+        self.assertRegex(email['raw'], 'Content-Type: text/plain')
+        self.assertRegex(email['raw'], 'Content-Transfer-Encoding: base64')
+        self.assertRegex(email['subject'],
+                         'ALARM LOW .test Alarm.* Target: some_where')
+        self.assertRegex(email['body'], "Alarm .test Alarm.")
+        self.assertRegex(email['body'], "On host .foo1.")
+        self.assertRegex(email['body'], UNICODE_CHAR)
 
         return_value = self.trap.pop(0)
         self.assertTrue(return_value)
@@ -223,15 +217,15 @@ class TestEmail(unittest.TestCase):
 
         email = _parse_email(self.trap.pop(0))
 
-        self.assertRegexpMatches(email['from'], "From: hpcs.mon@hp.com")
-        self.assertRegexpMatches(email['to'], "To: me@here.com")
-        self.assertRegexpMatches(email['raw'], "Content-Type: text/plain")
-        self.assertRegexpMatches(email['subject'], "Subject: ALARM LOW .test Alarm.")
-        self.assertRegexpMatches(email['body'], "Alarm .test Alarm.")
-        self.assertRegexpMatches(email['body'], "foo1")
-        self.assertRegexpMatches(email['body'], "foo2")
-        self.assertRegexpMatches(email['body'], "bar1")
-        self.assertRegexpMatches(email['body'], "bar2")
+        self.assertRegex(email['from'], "From: hpcs.mon@hp.com")
+        self.assertRegex(email['to'], "To: me@here.com")
+        self.assertRegex(email['raw'], "Content-Type: text/plain")
+        self.assertRegex(email['subject'], "Subject: ALARM LOW .test Alarm.")
+        self.assertRegex(email['body'], "Alarm .test Alarm.")
+        self.assertRegex(email['body'], "foo1")
+        self.assertRegex(email['body'], "foo2")
+        self.assertRegex(email['body'], "bar1")
+        self.assertRegex(email['body'], "bar2")
 
         return_value = self.trap.pop(0)
         self.assertTrue(return_value)
@@ -269,7 +263,7 @@ class TestEmail(unittest.TestCase):
 
         email = email_notifier.EmailNotifier(mock_log)
 
-        email.config(self.email_config)
+        email.config()
 
         alarm_dict = alarm(metrics)
 
@@ -313,7 +307,7 @@ class TestEmail(unittest.TestCase):
 
         email = email_notifier.EmailNotifier(mock_log)
 
-        email.config(self.email_config)
+        email.config()
 
         del self.trap[:]
 
@@ -324,8 +318,7 @@ class TestEmail(unittest.TestCase):
         email_result = email.send_notification(notification)
 
         self.assertFalse(email_result)
-        self.assertIn("Connecting to Email Server {}"
-                      .format(self.email_config['server']),
+        self.assertIn("Connecting to Email Server my.smtp.server",
                       self.trap)
 
     @mock.patch('monasca_notification.plugins.email_notifier.smtplib')
@@ -358,7 +351,7 @@ class TestEmail(unittest.TestCase):
 
         email = email_notifier.EmailNotifier(mock_log)
 
-        email.config(self.email_config)
+        email.config()
 
         alarm_dict = alarm(metrics)
 
@@ -398,7 +391,7 @@ class TestEmail(unittest.TestCase):
 
         email = email_notifier.EmailNotifier(mock_log)
 
-        email.config(self.email_config)
+        email.config()
 
         alarm_dict = alarm(metrics)
 
@@ -438,7 +431,7 @@ class TestEmail(unittest.TestCase):
 
         email = email_notifier.EmailNotifier(mock_log)
 
-        email.config(self.email_config)
+        email.config()
 
         alarm_dict = alarm(metrics)
 
@@ -471,7 +464,6 @@ class TestEmail(unittest.TestCase):
         mock_smtp.SMTPException = smtplib.SMTPException
 
         email = email_notifier.EmailNotifier(mock_log)
-        email.config(self.email_config)
 
         # Create alarm timestamp and timestamp for 'from' and 'to' dates in milliseconds.
         alarm_date = datetime.datetime(2017, 6, 7, 18, 0)
