@@ -1,4 +1,5 @@
 # (C) Copyright 2014-2016 Hewlett Packard Enterprise Development LP
+# Copyright 2017 Fujitsu LIMITED
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,13 +16,13 @@
 
 import mock
 import requests
-import unittest
 
 import six
 import ujson as json
 
 from monasca_notification import notification as m_notification
 from monasca_notification.plugins import webhook_notifier
+from tests import base
 
 if six.PY2:
     import Queue as queue
@@ -50,12 +51,14 @@ class requestsResponse(object):
         self.status_code = status
 
 
-class TestWebhook(unittest.TestCase):
+class TestWebhook(base.PluginTestCase):
+
     def setUp(self):
+        super(TestWebhook, self).setUp(webhook_notifier.register_opts)
         self.trap = queue.Queue()
-        self.webhook_config = {'timeout': 50}
 
     def tearDown(self):
+        super(TestWebhook, self).tearDown()
         self.assertTrue(self.trap.empty())
 
     def _http_post_200(self, url, data, headers, **kwargs):
@@ -84,8 +87,6 @@ class TestWebhook(unittest.TestCase):
 
         webhook = webhook_notifier.WebhookNotifier(mock_log)
 
-        webhook.config(self.webhook_config)
-
         metric = []
         metric_data = {'dimensions': {'hostname': 'foo1', 'service': 'bar1'}}
         metric.append(metric_data)
@@ -127,11 +128,11 @@ class TestWebhook(unittest.TestCase):
 
         error = self.trap.get()
 
-        self.assertNotRegexpMatches(error, "alarm_id.: .test Alarm")
-        self.assertNotRegexpMatches(error, "content-type.: .application/json")
+        self.assertNotRegex(error, "alarm_id.: .test Alarm")
+        self.assertNotRegex(error, "content-type.: .application/json")
 
-        self.assertRegexpMatches(error, "HTTP code 404")
-        self.assertRegexpMatches(error, "post on URL http://mock:3333/")
+        self.assertRegex(error, "HTTP code 404")
+        self.assertRegex(error, "post on URL http://mock:3333/")
 
         return_value = self.trap.get()
         self.assertFalse(return_value)
@@ -140,6 +141,7 @@ class TestWebhook(unittest.TestCase):
         """webhook timeout exception
         """
 
+        self.conf_override(group='webhook_notifier', timeout=50)
         self.notify(self._http_post_exception)
 
         result = self.trap.get()
@@ -148,11 +150,10 @@ class TestWebhook(unittest.TestCase):
 
         result = self.trap.get()
 
-        self.assertNotRegexpMatches(result, "alarm_id.: .test Alarm")
-        self.assertNotRegexpMatches(result, "content-type.: .application/json")
+        self.assertNotRegex(result, "alarm_id.: .test Alarm")
+        self.assertNotRegex(result, "content-type.: .application/json")
 
-        self.assertRegexpMatches(result, "Error trying to post on URL http://mock:3333/")
-        self.assertRaises(requests.exceptions.Timeout)
+        self.assertRegex(result, "Error trying to post on URL http://mock:3333/")
 
         return_value = self.trap.get()
         self.assertFalse(return_value)
